summaryrefslogtreecommitdiffstats
path: root/kmail/kmreaderwin.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmreaderwin.h')
-rw-r--r--kmail/kmreaderwin.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/kmail/kmreaderwin.h b/kmail/kmreaderwin.h
index 27bc33b0..4db8f05d 100644
--- a/kmail/kmreaderwin.h
+++ b/kmail/kmreaderwin.h
@@ -75,6 +75,7 @@ namespace KParts {
class KMReaderWin: public TQWidget, public KMail::Interface::Observer {
Q_OBJECT
+ TQ_OBJECT
friend void KMMimePartTree::itemClicked( TQListViewItem* item );
friend void KMMimePartTree::itemRightClicked( TQListViewItem* item, const TQPoint & );
@@ -85,7 +86,7 @@ class KMReaderWin: public TQWidget, public KMail::Interface::Observer {
friend class KMail::KHtmlPartHtmlWriter;
public:
- KMReaderWin( TQWidget *parent,
+ KMReaderWin( TQWidget *tqparent,
TQWidget *mainWindow,
KActionCollection *actionCollection,
const char *name=0,
@@ -323,7 +324,7 @@ public:
/* show or hide the list that points to the attachments */
void setShowAttachmentQuicklist( bool showAttachmentQuicklist = true ) { mShowAttachmentQuicklist = showAttachmentQuicklist; }
- // This controls whether a Toltec invitation is shown in its raw form or as a tqreplacement text.
+ // This controls whether a Toltec invitation is shown in its raw form or as a replacement text.
// This can be toggled with the "kmail:showRawToltecMail" link.
bool showRawToltecMail() const { return mShowRawToltecMail; }
void setShowRawToltecMail( bool showRawToltecMail ) { mShowRawToltecMail = showRawToltecMail; }
@@ -331,9 +332,9 @@ public:
/* retrieve BodyPartMemento of id \a which for partNode \a node */
KMail::Interface::BodyPartMemento * bodyPartMemento( const partNode * node, const TQCString & which ) const;
/* set/tqreplace BodyPartMemento \a memento of id \a which for
partNode \a node. If there was a BodyPartMemento registered
- already, tqreplaces (deletes) that one. */
+ already, replaces (deletes) that one. */
void setBodyPartMemento( const partNode * node, const TQCString & which, KMail::Interface::BodyPartMemento * memento );
/// Scrolls to the given attachment and marks it with a yellow border
@@ -347,7 +348,7 @@ private:
signals:
/** Emitted after parsing of a message to have it stored
in unencrypted state in it's folder. */
- void tqreplaceMsgByUnencryptedVersion();
+ void replaceMsgByUnencryptedVersion();
/** The user presses the right mouse button. 'url' may be 0. */
void popupMenu(KMMessage &msg, const KURL &url, const TQPoint& mousePos);
@@ -493,7 +494,7 @@ protected:
TQString writeMsgHeader(KMMessage* aMsg, partNode *vCardNode = 0, bool topLevel=false );
/** Writes the given message part to a temporary file and returns the
- name of this file or TQString::null if writing failed.
+ name of this file or TQString() if writing failed.
*/
TQString writeMessagePartToTempFile( KMMessagePart* msgPart, int partNumber );
@@ -331,9 +332,9 @@ public:
/* retrieve BodyPartMemento of id \a which for partNode \a node */
KMail::Interface::BodyPartMemento * bodyPartMemento( const partNode * node, const TQCString & which ) const;
- /* set/tqreplace BodyPartMemento \a memento of id \a which for
+ /* set/replace BodyPartMemento \a memento of id \a which for
partNode \a node. If there was a BodyPartMemento registered